/*******************************************************************************
Sam Langfield and Marco Pagano (2015)
"Bank bias in Europe: Effects on Systemic Risk and Growth"
Economic Policy
*******************************************************************************/

/*******************************************************************************
Risk regressions
*******************************************************************************/

/*******************************************************************************
HOUSEKEEPING
*******************************************************************************/

version 13.0

*Set your working directory here:
cd "C:\Users\SPL\Dropbox\Research\Pagano-Langfield_EP_Bank-bias\Data\CLEAN"

clear all
cap log close
set more off
set scheme s1color

insheet using B_NUS_yearly.csv, comma

merge m:1 countrycode year using X2_WorldBank_prepped, keep(1 3)

/*******************************************************************************
LABEL VARIABLES
*******************************************************************************/

label var company_number "Unique company identifier"
label var bbg_ticker "Bloomberg ticker"
label var bs_tot_asset "Total book value of assets (source: Bloomberg)"
label var bs_tot_liab "Total book value of liabilities (source: Bloomberg)"
label var liab_gdp "Total book value of liabilities divided by domestic GDP"
label var equity "Total book value of equity (source: Bloomberg)"
label var leverage "Book leverage (A/E) (source: Bloomberg)"
label var isin "ISIN code"

/*******************************************************************************
GENERATE VARIABLES
*******************************************************************************/

*Balance sheet variables
gen log_assets = log(bs_tot_asset)
gen log_liab = log(bs_tot_liab)

*Srisk variables
gen srisk_pos = srisk
replace srisk_pos = 0 if srisk<0
gen srisk_pos_ta = srisk_pos / bs_tot_asset

encode countrycode, gen(cocode)

local balancesheet L1.log_liab L1.liab_gdp L1.leverage 

tsset company_number year, yearly

save X3_NUS_prepped, replace

********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************
********************************************************************************


/*******************************************************************************
TABLE 1 AND FIGURE 9
*******************************************************************************/

use X3_NUS_prepped, clear

**********************
*Col 1
**********************
xtreg srisk_pos_ta c.L1.STR_ta_stockbond##d_crisis_hp_10pc i.year, fe vce(cluster company_number) 

outreg2 using "Z2_Table1", excel replace cttop("Housing market crisis")  ///
	drop(i.year) addnote("Specification: Fixed effects panel regression: -xtreg- in Stata. Data: Unbalanced panel of 510 listed banks, observed yearly, 2001-2012.")

**********************
*Col 2
**********************
xtreg srisk_pos_ta c.L1.STR_ta_stockbond##d_crisis_hp_10pc `balancesheet' i.year, fe vce(cluster company_number) 

outreg2 using "Z2_Table1", excel cttop("Housing market crisis")  ///
	drop(i.year) addnote("Specification: Fixed effects panel regression: -xtreg- in Stata. Data: Unbalanced panel of 510 listed banks, observed yearly, 2001-2012.")

margins, at(L1.STR_ta_stockbond=(-.9714913 -.9 (0.1) 1.6 1.611621)) over(d_crisis_hp_10pc)

marginsplot, ///
	recastci(rarea) ci1(color(gs14)) ci2(color(gs9)) ///
	recast(line) plot1(lcolor(gs7) lpattern("--") lwidth(medthick)) ///
				plot2(lcolor(gs0) lpattern(dot) lwidth(medthick)) ///
	xlabel(-.9714913 "5" .2410888 "20" .7547613 "50" 1.053002 "70" 1.611621 "95") ///				
		xtitle("", size(large)) ///
		ylabel(0 (0.02) 0.06) ///
		ytitle("", size(large)) ///
	legend(rows(1) order(- "Predicted effect during:" 4 "crises" 3 "no crisis") region(lcolor(white))) ///
	title("   Housing market crisis", size(large)) ///
	ysize(10) xsize(13) ///  
		graphregion(margin(medsmall)) ///
	name(hp, replace) scale(1)
	
**********************
*Col 3
**********************
xtreg srisk_pos_ta c.L1.STR_ta_stockbond##d_crisis_stkmkt_20pc i.year, fe vce(cluster company_number) 

outreg2 using "Z2_Table1", excel cttop("Stock market crisis") ///
	drop(i.year) addnote("Specification: Fixed effects panel regression: -xtreg- in Stata. Data: Unbalanced panel of 510 listed banks, observed yearly, 2001-2012.")

**********************
*Col 4
**********************
xtreg srisk_pos_ta c.L1.STR_ta_stockbond##d_crisis_stkmkt_20pc `balancesheet' i.year, fe vce(cluster company_number) 

outreg2 using "Z2_Table1", excel cttop("Stock market crisis") ///
	drop(i.year) addnote("Specification: Fixed effects panel regression: -xtreg- in Stata. Data: Unbalanced panel of 510 listed banks, observed yearly, 2001-2012.")

margins, at(L1.STR_ta_stockbond=(-.9714913 -.9 (0.1) 1.6 1.611621)) over(d_crisis_stkmkt_20pc)
	
marginsplot, ///
	recastci(rarea) ci1(color(gs14)) ci2(color(gs9)) ///
	recast(line) plot1(lcolor(gs7) lpattern("--") lwidth(medthick)) /// 
				plot2(lcolor(gs0) lpattern(dot) lwidth(medthick)) ///
	xlabel(-.9714913 "5" .2410888 "20" .7547613 "50" 1.053002 "70" 1.611621 "95") ///			
		xtitle("", size(large)) ///
		ylabel(0 (0.02) 0.06) ///
		ytitle("") ///
	legend(rows(1) order(3 4) region(lcolor(white)) ///
		label(3 "No crisis") label(4 "Stock market crash")) ///
	title("   Stock market crisis", size(large)) ///
	ysize(1) xsize(1) ///  
	graphregion(margin(medsmall)) ///
	name(stk, replace) scale(1)
	
grc1leg hp stk, ///
	scale(1) name("combine", replace) graphregion(margin(medsmall)) legendfrom(hp) rows(1) ///
	l2title("Systemic risk intensity", size(med)) l1title("(systemic risk divided by a bank's total assets)", size(medsmall)) ///
	b1title("Bank-market ratio", size(med)) span position(12) ///
	b2title("(percentile in the distribution of" "bank total assets to stock and bond market cap)", size(medsmall))

graph display combine, ysize(10) xsize(13)

graph export Z_Fig9.emf, replace


/*******************************************************************************
TABLE 2: Robustness check using trimmed least squares estimator
Download the -pantob- program from Bo Honore's homepage:
http://www.princeton.edu/~honore/stata/#1._Pantob_version_0.6
*******************************************************************************/

use X3_NUS_prepped, clear

drop if missing(srisk)
tabulate year, gen(d_year)

tsset company_number year, yearly

gen L1STR_ta_stockbond = L1.STR_ta_stockbond
gen STRnHouseCrisis = L1STR_ta_stockbond*d_crisis_hp_10pc
gen L1log_liab = L1.log_liab
gen L1liab_gdp = L1.liab_gdp
gen L1leverage = L1.leverage

gen STRnStockCrisis = L1STR_ta_stockbond*d_crisis_stkmkt_20pc

**********************
*Col 1
**********************
pantob srisk_pos_ta L1STR_ta_stockbond d_crisis_hp_10pc STRnHouseCrisis d_year3 d_year4 d_year5 d_year6 d_year7 d_year8 d_year9 d_year10 d_year11 d_year12 company_number, details

outreg2 using "Z2_Table2", excel replace cttop("Housing market crisis")  ///
	drop(d_year*) addnote("Specification: Fixed effects panel regression: -xtreg- in Stata. Data: Unbalanced panel of 510 listed banks, observed yearly, 2001-2012.")

**********************
*Col 2
**********************
pantob srisk_pos_ta L1STR_ta_stockbond d_crisis_hp_10pc STRnHouseCrisis L1log_liab L1liab_gdp L1leverage d_year3 d_year4 d_year5 d_year6 d_year7 d_year8 d_year9 d_year10 d_year11 d_year12 company_number, details

outreg2 using "Z2_Table2", excel cttop("Housing market crisis")  ///
	drop(d_year*) addnote("Specification: Fixed effects panel regression: -xtreg- in Stata. Data: Unbalanced panel of 510 listed banks, observed yearly, 2001-2012.")

**********************
*Col 3
**********************
pantob srisk_pos_ta L1STR_ta_stockbond d_crisis_stkmkt_20pc STRnStockCrisis d_year3 d_year4 d_year5 d_year6 d_year7 d_year8 d_year9 d_year10 d_year11 d_year12 company_number, details

outreg2 using "Z2_Table2", excel cttop("Stock market crisis")  ///
	drop(d_year*) addnote("Specification: Fixed effects panel regression: -xtreg- in Stata. Data: Unbalanced panel of 510 listed banks, observed yearly, 2001-2012.")

**********************
*Col 4
**********************
pantob srisk_pos_ta L1STR_ta_stockbond d_crisis_stkmkt_20pc STRnStockCrisis L1log_liab L1liab_gdp L1leverage d_year3 d_year4 d_year5 d_year6 d_year7 d_year8 d_year9 d_year10 d_year11 d_year12 company_number, details

outreg2 using "Z2_Table2", excel cttop("Stock market crisis")  ///
	drop(d_year*) addnote("Specification: Fixed effects panel regression: -xtreg- in Stata. Data: Unbalanced panel of 510 listed banks, observed yearly, 2001-2012.")



/*******************************************************************************
Predicted effect (for calculations in paper para begininning "To garner further insight...")
*******************************************************************************/

use X3_NUS_prepped, clear

*Re-run Table 1, col I
xtreg srisk_pos_ta c.L1.STR_ta_stockbond##d_crisis_hp_10pc i.year, fe vce(cluster company_number) 

margins, at(L1.STR_ta_stockbond=(1.1515791 1.3228805)) atmeans over(d_crisis_hp_10pc) //To calculate the predicted economic effect of the actual increase in the bank-market ratio between 1990 and 2011. 

/*
Print of results from previous -margin- command:

--------------------------------------------------------------------------------------
                     |            Delta-method
                     |     Margin   Std. Err.      z    P>|z|     [95% Conf. Interval]
---------------------+----------------------------------------------------------------
_at#d_crisis_hp_10pc |
                1 0  |   .0149401   .0058041     2.57   0.010     .0035643    .0263159
                1 1  |   .0403761   .0061964     6.52   0.000     .0282315    .0525208
                2 0  |   .0151824   .0064615     2.35   0.019     .0025181    .0278466
                2 1  |   .0425265   .0068827     6.18   0.000     .0290366    .0560164
--------------------------------------------------------------------------------------

"The estimates reported in column I of Table 1 imply that such an increase in the 
bank-market ratio at the country-level is associated with 2% greater systemic risk 
intensity during normal times and 5% during housing market crises."

--> To replicate 2% during normal times, calculate (.0151824/.0149401)-1 = 0.016218
--> To replicate 5% during housing crises, calculate (.0425265/.0403761)-1 = 0.053259
*/

margins, at(L1.STR_ta_stockbond=(1.1515791 0.512555460738297)) atmeans over(d_crisis_hp_10pc) //To calculate the predicted economic effect of a hypothetical scenario in which the bank-market ratio falls from 3.2 in 1990 to 1.7 in 2011.

/*
--------------------------------------------------------------------------------------
                     |            Delta-method
                     |     Margin   Std. Err.      z    P>|z|     [95% Conf. Interval]
---------------------+----------------------------------------------------------------
_at#d_crisis_hp_10pc |
                1 0  |   .0149401   .0058041     2.57   0.010     .0035643    .0263159
                1 1  |   .0403761   .0061964     6.52   0.000     .0282315    .0525208
                2 0  |   .0140364    .003352     4.19   0.000     .0074665    .0206062
                2 1  |   .0323543   .0036493     8.87   0.000     .0252019    .0395067
--------------------------------------------------------------------------------------

"According to our estimates, this hypothetical decrease in the bank-market ratio would 
have been associated with a reduction in European banks average systemic risk intensity 
of 6% in normal times and 20% during housing market crises."

--> To replicate 6% during normal times, calculate (.0140364/.0149401)-1 = -0.060488
--> To replicate 20% during housing crises, calculate (.0323543/.0403761) = -0.19868
*/
	
